summaryrefslogtreecommitdiff
path: root/contrib
diff options
context:
space:
mode:
authorChris Evich <cevich@redhat.com>2021-06-30 11:39:19 -0400
committerChris Evich <cevich@redhat.com>2021-06-30 11:39:19 -0400
commit40ef17ac282fab7229a121635f81842fb5d65eb0 (patch)
tree8771790b2fadb7b0a47ce9d67c4440426444c6f0 /contrib
parent056f492f59c333d521ebbbe186abde0278e815db (diff)
downloadpodman-40ef17ac282fab7229a121635f81842fb5d65eb0.tar.gz
podman-40ef17ac282fab7229a121635f81842fb5d65eb0.tar.bz2
podman-40ef17ac282fab7229a121635f81842fb5d65eb0.zip
Cirrus: Fixes due to master->main rename
Signed-off-by: Chris Evich <cevich@redhat.com>
Diffstat (limited to 'contrib')
-rw-r--r--contrib/cirrus/lib.sh2
-rwxr-xr-xcontrib/cirrus/pr-should-include-tests2
-rwxr-xr-xcontrib/cirrus/runner.sh4
3 files changed, 4 insertions, 4 deletions
diff --git a/contrib/cirrus/lib.sh b/contrib/cirrus/lib.sh
index 16eb6735a..9a7bfba8f 100644
--- a/contrib/cirrus/lib.sh
+++ b/contrib/cirrus/lib.sh
@@ -74,7 +74,7 @@ PODMAN_SERVER_LOG=$CIRRUS_WORKING_DIR/server.log
# Defaults when not running under CI
export CI="${CI:-false}"
CIRRUS_CI="${CIRRUS_CI:-false}"
-DEST_BRANCH="${DEST_BRANCH:-master}"
+DEST_BRANCH="${DEST_BRANCH:-main}"
CONTINUOUS_INTEGRATION="${CONTINUOUS_INTEGRATION:-false}"
CIRRUS_REPO_NAME=${CIRRUS_REPO_NAME:-podman}
# Cirrus only sets $CIRRUS_BASE_SHA properly for PRs, but $EPOCH_TEST_COMMIT
diff --git a/contrib/cirrus/pr-should-include-tests b/contrib/cirrus/pr-should-include-tests
index 392136fdb..0124e238e 100755
--- a/contrib/cirrus/pr-should-include-tests
+++ b/contrib/cirrus/pr-should-include-tests
@@ -16,7 +16,7 @@ fi
# HEAD should be good enough, but the CIRRUS envariable allows us to test
head=${CIRRUS_CHANGE_IN_REPO:-HEAD}
# Base of this PR. Here we absolutely rely on cirrus.
-base=$(git merge-base ${DEST_BRANCH:-master} $head)
+base=$(git merge-base ${DEST_BRANCH:-main} $head)
# This gives us a list of files touched in all commits, e.g.
# A foo.c
diff --git a/contrib/cirrus/runner.sh b/contrib/cirrus/runner.sh
index 47f3c9405..c46258cd6 100755
--- a/contrib/cirrus/runner.sh
+++ b/contrib/cirrus/runner.sh
@@ -145,9 +145,9 @@ function _run_swagger() {
elif [[ -n "$CIRRUS_TAG" ]]; then
upload_bucket="libpod-master-releases"
upload_filename="swagger-$CIRRUS_TAG.yaml"
- elif [[ "$CIRRUS_BRANCH" == "master" ]]; then
+ elif [[ "$CIRRUS_BRANCH" == "main" ]]; then
upload_bucket="libpod-master-releases"
# readthedocs versioning uses "latest" for "master" (default) branch
upload_filename="swagger-latest.yaml"
elif [[ -n "$CIRRUS_BRANCH" ]]; then
upload_bucket="libpod-master-releases"
@@ -145,9 +145,9 @@ function _run_swagger() {
upload_bucket="libpod-master-releases"
- # readthedocs versioning uses "latest" for "master" (default) branch
+ # readthedocs versioning uses "latest" for "main" (default) branch
upload_filename="swagger-latest.yaml"
elif [[ -n "$CIRRUS_BRANCH" ]]; then